.. image:: https://img.shields.io/pypi/v/jaraco.site.svg
   :target: https://pypi.org/project/jaraco.site

.. image:: https://img.shields.io/pypi/pyversions/jaraco.site.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.site/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.site
